C++ library
===========


The full documentation for the C++ library can be build from the source code
using `doxygen <http://www.doxygen.nl/>`_.
For convenience we provide links the main functions on this page.

.. toctree::
       :maxdepth: 2
       :titlesonly:
       :glob:
       
       cppdocs/*

